@@ -435,7 +435,7 @@ OPGP_ERROR_STATUS GP211_set_status(OPGP_CARD_CONTEXT cardContext, OPGP_CARD_INFO
 //! \brief GlobalPlatform2.1.1: Mutual authentication.
 OPGP_API
 OPGP_ERROR_STATUS GP211_mutual_authentication(OPGP_CARD_CONTEXT cardContext, OPGP_CARD_INFO cardInfo,
-						   BYTE baseKey[16], BYTE S_ENC[32], BYTE S_MAC[32],
+						   BYTE baseKey[32], BYTE S_ENC[32], BYTE S_MAC[32],
 						   BYTE DEK[32], DWORD keyLength, BYTE keySetVersion,
 						   BYTE keyIndex, BYTE secureChannelProtocol,
 						   BYTE secureChannelProtocolImpl,
@@ -511,6 +511,12 @@ OPGP_ERROR_STATUS GP211_put_secure_channel_keys(OPGP_CARD_CONTEXT cardContext, O
 							 BYTE keySetVersion, BYTE newKeySetVersion, BYTE baseKey[32],
 							 BYTE newS_ENC[32], BYTE newS_MAC[32], BYTE newDEK[32], DWORD keyLength);
 
+//! \brief GlobalPlatform2.1.1: replaces or adds a secure channel key set consisting of S-ENC, S-MAC and DEK.
+OPGP_API
+OPGP_ERROR_STATUS GP211_put_secure_channel_keys_with_key_type(OPGP_CARD_CONTEXT cardContext, OPGP_CARD_INFO cardInfo, GP211_SECURITY_INFO *secInfo,
+							 BYTE keySetVersion, BYTE newKeySetVersion, BYTE baseKey[32],
+							 BYTE newS_ENC[32], BYTE newS_MAC[32], BYTE newDEK[32], DWORD keyLength, BYTE keyType);
+
 //! \brief GlobalPlatform2.1.1: deletes a key or multiple keys.
 OPGP_API
 OPGP_ERROR_STATUS GP211_delete_key(OPGP_CARD_CONTEXT cardContext, OPGP_CARD_INFO cardInfo, GP211_SECURITY_INFO *secInfo,
@@ -764,6 +770,10 @@ OPGP_ERROR_STATUS OPGP_select_channel(OPGP_CARD_INFO *cardInfo, BYTE channelNumb
 OPGP_ERROR_STATUS OPGP_calculate_key_check_value(GP211_SECURITY_INFO *secInfo,
 	PBYTE keyData, DWORD keyDataLength, BYTE keyCheckValue[3]);
 
+//! \brief Calculates the key check value of a key.
+OPGP_ERROR_STATUS OPGP_calculate_key_check_value_with_key_type(GP211_SECURITY_INFO *secInfo,
+	BYTE keyType, PBYTE keyData, DWORD keyDataLength, BYTE keyCheckValue[3]);
+
 //! \brief Encrypts sensitive data like keys or other data which is used in STORE DATA.
 OPGP_ERROR_STATUS OPGP_encrypt_sensitive_data(GP211_SECURITY_INFO *secInfo,
 	PBYTE data, DWORD dataLength,
